==> traintrain_0.1.1-1.tar.gz: traintrain-0.1.1/src/opt/traintrain/view/TrainTrainView.py <==
﻿#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os, sys, time
from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import Qt
from DebugLog import DebugLog
from TrainTrainModel import TrainTrainModel
from RideView import RideView
from Settings import SettingsDlg

class TrainTrainView(QtGui.QMainWindow):

   def __init__(self, argv, parent=None):
      QtGui.QMainWindow.__init__(self, parent)

      DebugLog("TrainTrainView::Init")
      self.offline = os.environ.has_key('OFFLINE')

      desktop = QtGui.QApplication.desktop()
      width = desktop.screenGeometry().width()
      height = desktop.screenGeometry().height()
      self.setMaximumSize(QtCore.QSize(width, width))
      self.setMinimumSize(QtCore.QSize(height, width))

      try:
         self.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
      except AttributeError:
         # not on Maemo5
         self.setMaximumSize(QtCore.QSize(800, 800))
         self.setMinimumSize(QtCore.QSize(480, 800))
         pass


      self.setWindowTitle('TrainTrain')

      self.model = TrainTrainModel()
      self.model.SetOnline(True)
      self.views = dict()

      self.CreateAppLayouts()
      self.ReInit()

   def ReInit(self):
      DebugLog("TrainTrainView::ReInit")

      self.updateCpt=0
      for view in self.views.values():
         self.RemoveView(view)
      self.model.InitDatas()
      self.PrepareView()
      self.SetLoading(True)

   def Settings(self):
      dlg = SettingsDlg(self.model.garesConf)
      dlg.exec_()
      ride = dlg.added
      if ride:
         rideModel = self.model.CreateAndAddRide(ride)
         self.AppendRideView(rideModel)

   def AppendRideView(self, rideModel):
      view = RideView(rideModel, self)
      self.views[rideModel.id] = view
      self.vLayout.addWidget( view )
      view.Busy()

   def PrepareView(self):
      DebugLog("TrainTrainView::PrepareView")
      for rideModel in self.model.GetRidesModel():
         self.AppendRideView(rideModel)

   def RemoveView(self, view):
      DebugLog("TrainTrainView::RemoveView(%s)"%view.model.id)
      self.model.RemoveRideModel(view.model)
      self.vLayout.removeWidget(view)
      del self.views[view.model.id]

   def CreateAppLayouts(self):
      DebugLog("TrainTrainView::CreateAppLayouts")

      add = QtGui.QAction(u'Ajouter un trajet', self)
      add.setShortcut('Ctrl+A')
      self.connect(add, QtCore.SIGNAL('triggered()'),self.Settings)

      update = QtGui.QAction(u'Rafraichir', self)
      update.setShortcut('Ctrl+R')
      self.connect(update, QtCore.SIGNAL('triggered()'), self.Update)

      about = QtGui.QAction(u'A propos...', self)
      self.connect(about, QtCore.SIGNAL('triggered()'), self.About)

      menubar = self.menuBar()
      file = menubar.addMenu('&Options')
      file.addAction(add)
      file.addAction(update)
      file.addAction(about)

      self.scrollArea = QtGui.QScrollArea(self)#.centralWidget)
      self.scrollArea.setWidgetResizable(True)

      self.scrollAreaWidgetContents = QtGui.QWidget(self.scrollArea)
      self.vLayout = QtGui.QVBoxLayout()
      self.vLayout.setSpacing(0)
      self.vLayout.setMargin(0)
      self.vLayout.setAlignment(Qt.AlignTop)

      self.tLayout = QtGui.QVBoxLayout()
      self.tLayout.setSpacing(0)
      self.tLayout.setMargin(0)
      self.tLayout.addLayout(self.vLayout)
      addButton = QtGui.QPushButton('Ajouter un trajet')
      self.tLayout.addWidget(addButton)
      addButton.clicked.connect(self.Settings)
      addButton.setDefault(True)
      addButton.setStyleSheet('background-color:#2684DB; color: #fff; margin: 5px; padding: 5px;')

      self.scrollAreaWidgetContents.setLayout( self.tLayout )
      self.scrollAreaWidgetContents.setStyleSheet("background: #fff; margin: 0; padding: 0;")

      self.scrollArea.setWidget(self.scrollAreaWidgetContents)
      self.setCentralWidget(self.scrollArea)

      self.firstTime = True
      self.connect(self.model, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)

      self.connect(QtGui.QApplication.desktop(), QtCore.SIGNAL('resized(int)'), self.Resized)

   def Resized(self, val):
      desktop = QtGui.QApplication.desktop()

      if desktop.screenGeometry().width() > desktop.screenGeometry().height():
         print "<p align=\"center\">In Landscape Mode</p>"
      else:
         print "<p align=\"center\">In Portrait Mode</p>"

   def Update(self):
      DebugLog("TrainTrainView::Update")
      self.updateCpt=0
      self.SetLoading(True)

      for view in self.views.values():
         view.Busy()
      self.model.RefreshDatas()

   def Extracted(self, rideModel):
      DebugLog("TrainTrainView::Extracted")
      self.updateCpt+=1
      self.views[rideModel.id].UpdateRides()

      if self.updateCpt>=len(self.views):
         self.SetLoading(False)

   def SetLoading(self, b):
      try:
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, b)
      except AttributeError:
         # not on Maemo5
         pass

   def About(self):
      QtGui.QMessageBox.about(self, "A propos", u'TrainTrain\nDéveloppé par Gérald Fauvelle\nhttp://projects.forum.nokia.com/TrainTrain')
      return

   def closeEvent(self, event):
      if self.model.garesConf.hasChanged:
         self.model.garesConf.Write()
      event.accept()

==> traintrain_0.1.2-1.tar.gz: traintrain-0.1.2/src/opt/traintrain/view/TrainTrainView.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os, sys, time
from PyQt4 import QtGui, QtCore
from PyQt4.QtCore import Qt
from utils.DebugLog import DebugLog
from model.TrainTrainModel import TrainTrainModel
from view.RideView import RideView
from view.Settings import SettingsDlg

class TrainTrainView(QtGui.QMainWindow):

   def __init__(self, argv, parent=None):
      QtGui.QMainWindow.__init__(self, parent)

      DebugLog("TrainTrainView::Init")
      self.offline = os.environ.has_key('OFFLINE')

      desktop = QtGui.QApplication.desktop()
      width = desktop.screenGeometry().width()
      height = desktop.screenGeometry().height()
      self.setMaximumSize(QtCore.QSize(width, width))
      self.setMinimumSize(QtCore.QSize(height, width))

      try:
         self.setAttribute(QtCore.Qt.WA_Maemo5AutoOrientation, True)
      except AttributeError:
         # not on Maemo5
         self.setMaximumSize(QtCore.QSize(800, 800))
         self.setMinimumSize(QtCore.QSize(480, 800))
         pass


      self.setWindowTitle('TrainTrain')

      self.model = TrainTrainModel()
      self.model.SetOnline(True)
      self.views = dict()

      self.CreateAppLayouts()
      self.ReInit()

   def ReInit(self):
      DebugLog("TrainTrainView::ReInit")

      self.updateCpt=0
      for view in self.views.values():
         self.RemoveView(view)
      self.model.InitDatas()
      self.PrepareView()
      self.SetLoading(True)

   def Settings(self):
      dlg = SettingsDlg(self.model.garesConf)
      dlg.exec_()
      ride = dlg.added
      if ride:
         rideModel = self.model.CreateAndAddRide(ride)
         self.AppendRideView(rideModel)

   def AppendRideView(self, rideModel):
      view = RideView(rideModel, self)
      self.views[rideModel.id] = view
      self.vLayout.addWidget( view )
      view.Busy()

   def PrepareView(self):
      DebugLog("TrainTrainView::PrepareView")
      for rideModel in self.model.GetRidesModel():
         self.AppendRideView(rideModel)

   def RemoveView(self, view):
      DebugLog("TrainTrainView::RemoveView(%s)"%view.model.id)
      self.model.RemoveRideModel(view.model)
      self.vLayout.removeWidget(view)
      del self.views[view.model.id]

   def CreateAppLayouts(self):
      DebugLog("TrainTrainView::CreateAppLayouts")

      add = QtGui.QAction(u'Ajouter un trajet', self)
      add.setShortcut('Ctrl+A')
      self.connect(add, QtCore.SIGNAL('triggered()'),self.Settings)

      update = QtGui.QAction(u'Rafraichir', self)
      update.setShortcut('Ctrl+R')
      self.connect(update, QtCore.SIGNAL('triggered()'), self.Update)

      about = QtGui.QAction(u'A propos...', self)
      self.connect(about, QtCore.SIGNAL('triggered()'), self.About)

      menubar = self.menuBar()
      file = menubar.addMenu('&Options')
      file.addAction(add)
      file.addAction(update)
      file.addAction(about)

      self.scrollArea = QtGui.QScrollArea(self)#.centralWidget)
      self.scrollArea.setWidgetResizable(True)

      self.scrollAreaWidgetContents = QtGui.QWidget(self.scrollArea)
      self.vLayout = QtGui.QVBoxLayout()
      self.vLayout.setSpacing(0)
      self.vLayout.setMargin(0)
      self.vLayout.setAlignment(Qt.AlignTop)

      self.tLayout = QtGui.QVBoxLayout()
      self.tLayout.setSpacing(0)
      self.tLayout.setMargin(0)
      self.tLayout.addLayout(self.vLayout)
      addButton = QtGui.QPushButton('Ajouter un trajet')
      self.tLayout.addWidget(addButton)
      addButton.clicked.connect(self.Settings)
      addButton.setDefault(True)
      addButton.setStyleSheet('background-color:#2684DB; color: #fff; margin: 5px; padding: 5px;')

      self.scrollAreaWidgetContents.setLayout( self.tLayout )
      self.scrollAreaWidgetContents.setStyleSheet("background: #fff; margin: 0; padding: 0;")

      self.scrollArea.setWidget(self.scrollAreaWidgetContents)
      self.setCentralWidget(self.scrollArea)

      self.firstTime = True
      self.connect(self.model, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)

      self.connect(QtGui.QApplication.desktop(), QtCore.SIGNAL('resized(int)'), self.Resized)

   def Resized(self, val):
      desktop = QtGui.QApplication.desktop()

      # if desktop.screenGeometry().width() > desktop.screenGeometry().height():
         # print "<p align=\"center\">In Landscape Mode</p>"
      # else:
         # print "<p align=\"center\">In Portrait Mode</p>"

   def Update(self):
      DebugLog("TrainTrainView::Update")
      self.updateCpt=0
      self.SetLoading(True)

      for view in self.views.values():
         view.Busy()
      self.model.RefreshDatas()

   def Extracted(self, rideModel):
      DebugLog("TrainTrainView::Extracted")
      self.updateCpt+=1
      self.views[rideModel.id].UpdateRides()

      if self.updateCpt>=len(self.views):
         self.SetLoading(False)

   def SetLoading(self, b):
      try:
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, b)
      except AttributeError:
         # not on Maemo5
         pass

   def About(self):
      QtGui.QMessageBox.about(self, "A propos", u'TrainTrain\nDéveloppé par Gérald Fauvelle\nhttp://projects.forum.nokia.com/TrainTrain')
      return

   def closeEvent(self, event):
      if self.model.garesConf.hasChanged:
         self.model.garesConf.Write()
      event.accept()
